Struct
QmiIndicationPdcDeactivateConfigOutput
since: 1.18
Description [src]
struct QmiIndicationPdcDeactivateConfigOutput {
/* No available fields */
}
The QmiIndicationPdcDeactivateConfigOutput structure contains private data and should only be accessed
using the provided API.
Available since: 1.18
Instance methods
qmi_indication_pdc_deactivate_config_output_get_indication_result
Get the ‘Indication Result’ field from self.
since: 1.18
qmi_indication_pdc_deactivate_config_output_ref
Atomically increments the reference count of self by one.
since: 1.18
qmi_indication_pdc_deactivate_config_output_unref
Atomically decrements the reference count of self by one.
If the reference count drops to 0, self is completely disposed.
since: 1.18